@@ -1,3 +1,18 @@
+#  Licensed to the Apache Software Foundation (ASF) under one or more
+#  contributor license agreements.  See the NOTICE file distributed with
+#  this work for additional information regarding copyright ownership.
+#  The ASF licenses this file to You under the Apache License, Version 2.0
+#  (the "License"); you may not use this file except in compliance with
+#  the License.  You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+#  Unless required by applicable law or agreed to in writing, software
+#  distributed under the License is distributed on an "AS IS" BASIS,
+#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#  See the License for the specific language governing permissions and
+#  limitations under the License.
+
 from pyspark.ml.util import JavaMLWritable
 from pyspark.ml.wrapper import JavaModel, JavaEstimator
 from pyspark.ml.param.shared import Param, TypeConverters
@@ -88,6 +103,17 @@ class HasStorageRef:
         return self.getOrDefault("storageRef")
 
 
+class HasBatchedAnnotate:
+
+    batchSize = Param(Params._dummy(), "batchSize", "Size of every batch", TypeConverters.toInt)
+
+    def setBatchSize(self, v):
+        return self._set(batchSize=v)
+
+    def getBatchSize(self):
+        return self.getOrDefault("batchSize")
+
+
 class HasCaseSensitiveProperties:
     caseSensitive = Param(Params._dummy(),
                           "caseSensitive",
